@@ -150,7 +150,6 @@ SpMat<eT>::const_iterator::const_iterator(const typename SpMat<eT>::const_iterat
 
 template<typename eT>
 inline
-arma_hot
 typename SpMat<eT>::const_iterator&
 SpMat<eT>::const_iterator::operator++()
   {
@@ -175,7 +174,6 @@ SpMat<eT>::const_iterator::operator++()
 
 template<typename eT>
 inline
-arma_warn_unused
 typename SpMat<eT>::const_iterator
 SpMat<eT>::const_iterator::operator++(int)
   {
@@ -190,7 +188,6 @@ SpMat<eT>::const_iterator::operator++(int)
 
 template<typename eT>
 inline
-arma_hot
 typename SpMat<eT>::const_iterator&
 SpMat<eT>::const_iterator::operator--()
   {
@@ -209,7 +206,6 @@ SpMat<eT>::const_iterator::operator--()
 
 template<typename eT>
 inline
-arma_warn_unused
 typename SpMat<eT>::const_iterator
 SpMat<eT>::const_iterator::operator--(int)
   {
@@ -224,7 +220,6 @@ SpMat<eT>::const_iterator::operator--(int)
 
 template<typename eT>
 inline
-arma_hot
 bool
 SpMat<eT>::const_iterator::operator==(const const_iterator& rhs) const
   {
@@ -235,7 +230,6 @@ SpMat<eT>::const_iterator::operator==(const const_iterator& rhs) const
 
 template<typename eT>
 inline
-arma_hot
 bool
 SpMat<eT>::const_iterator::operator!=(const const_iterator& rhs) const
   {
@@ -246,7 +240,6 @@ SpMat<eT>::const_iterator::operator!=(const const_iterator& rhs) const
 
 template<typename eT>
 inline
-arma_hot
 bool
 SpMat<eT>::const_iterator::operator==(const typename SpSubview<eT>::const_iterator& rhs) const
   {
@@ -257,7 +250,6 @@ SpMat<eT>::const_iterator::operator==(const typename SpSubview<eT>::const_iterat
 
 template<typename eT>
 inline
-arma_hot
 bool
 SpMat<eT>::const_iterator::operator!=(const typename SpSubview<eT>::const_iterator& rhs) const
   {
@@ -268,7 +260,6 @@ SpMat<eT>::const_iterator::operator!=(const typename SpSubview<eT>::const_iterat
 
 template<typename eT>
 inline
-arma_hot
 bool
 SpMat<eT>::const_iterator::operator==(const const_row_iterator& rhs) const
   {
@@ -279,7 +270,6 @@ SpMat<eT>::const_iterator::operator==(const const_row_iterator& rhs) const
 
 template<typename eT>
 inline
-arma_hot
 bool
 SpMat<eT>::const_iterator::operator!=(const const_row_iterator& rhs) const
   {
@@ -290,7 +280,6 @@ SpMat<eT>::const_iterator::operator!=(const const_row_iterator& rhs) const
 
 template<typename eT>
 inline
-arma_hot
 bool
 SpMat<eT>::const_iterator::operator==(const typename SpSubview<eT>::const_row_iterator& rhs) const
   {
@@ -301,7 +290,6 @@ SpMat<eT>::const_iterator::operator==(const typename SpSubview<eT>::const_row_it
 
 template<typename eT>
 inline
-arma_hot
 bool
 SpMat<eT>::const_iterator::operator!=(const typename SpSubview<eT>::const_row_iterator& rhs) const
   {
@@ -316,7 +304,6 @@ SpMat<eT>::const_iterator::operator!=(const typename SpSubview<eT>::const_row_it
 
 template<typename eT>
 inline
-arma_hot
 SpValProxy< SpMat<eT> >
 SpMat<eT>::iterator::operator*()
   {
@@ -331,7 +318,6 @@ SpMat<eT>::iterator::operator*()
 
 template<typename eT>
 inline
-arma_hot
 typename SpMat<eT>::iterator&
 SpMat<eT>::iterator::operator++()
   {
@@ -344,7 +330,6 @@ SpMat<eT>::iterator::operator++()
 
 template<typename eT>
 inline
-arma_warn_unused
 typename SpMat<eT>::iterator
 SpMat<eT>::iterator::operator++(int)
   {
@@ -359,7 +344,6 @@ SpMat<eT>::iterator::operator++(int)
 
 template<typename eT>
 inline
-arma_hot
 typename SpMat<eT>::iterator&
 SpMat<eT>::iterator::operator--()
   {
@@ -372,7 +356,6 @@ SpMat<eT>::iterator::operator--()
 
 template<typename eT>
 inline
-arma_warn_unused
 typename SpMat<eT>::iterator
 SpMat<eT>::iterator::operator--(int)
   {
@@ -573,7 +556,6 @@ SpMat<eT>::const_row_iterator::const_row_iterator(const typename SpMat<eT>::cons
  */
 template<typename eT>
 inline
-arma_hot
 typename SpMat<eT>::const_row_iterator&
 SpMat<eT>::const_row_iterator::operator++()
   {
@@ -699,7 +681,6 @@ SpMat<eT>::const_row_iterator::operator++()
  */
 template<typename eT>
 inline
-arma_warn_unused
 typename SpMat<eT>::const_row_iterator
 SpMat<eT>::const_row_iterator::operator++(int)
   {
@@ -717,7 +698,6 @@ SpMat<eT>::const_row_iterator::operator++(int)
  */
 template<typename eT>
 inline
-arma_hot
 typename SpMat<eT>::const_row_iterator&
 SpMat<eT>::const_row_iterator::operator--()
   {
@@ -820,7 +800,6 @@ SpMat<eT>::const_row_iterator::operator--()
  */
 template<typename eT>
 inline
-arma_warn_unused
 typename SpMat<eT>::const_row_iterator
 SpMat<eT>::const_row_iterator::operator--(int)
   {
@@ -835,7 +814,6 @@ SpMat<eT>::const_row_iterator::operator--(int)
 
 template<typename eT>
 inline
-arma_hot
 bool
 SpMat<eT>::const_row_iterator::operator==(const const_iterator& rhs) const
   {
@@ -846,7 +824,6 @@ SpMat<eT>::const_row_iterator::operator==(const const_iterator& rhs) const
 
 template<typename eT>
 inline
-arma_hot
 bool
 SpMat<eT>::const_row_iterator::operator!=(const const_iterator& rhs) const
   {
@@ -857,7 +834,6 @@ SpMat<eT>::const_row_iterator::operator!=(const const_iterator& rhs) const
 
 template<typename eT>
 inline
-arma_hot
 bool
 SpMat<eT>::const_row_iterator::operator==(const typename SpSubview<eT>::const_iterator& rhs) const
   {
@@ -868,7 +844,6 @@ SpMat<eT>::const_row_iterator::operator==(const typename SpSubview<eT>::const_it
 
 template<typename eT>
 inline
-arma_hot
 bool
 SpMat<eT>::const_row_iterator::operator!=(const typename SpSubview<eT>::const_iterator& rhs) const
   {
@@ -879,7 +854,6 @@ SpMat<eT>::const_row_iterator::operator!=(const typename SpSubview<eT>::const_it
 
 template<typename eT>
 inline
-arma_hot
 bool
 SpMat<eT>::const_row_iterator::operator==(const const_row_iterator& rhs) const
   {
@@ -890,7 +864,6 @@ SpMat<eT>::const_row_iterator::operator==(const const_row_iterator& rhs) const
 
 template<typename eT>
 inline
-arma_hot
 bool
 SpMat<eT>::const_row_iterator::operator!=(const const_row_iterator& rhs) const
   {
@@ -901,7 +874,6 @@ SpMat<eT>::const_row_iterator::operator!=(const const_row_iterator& rhs) const
 
 template<typename eT>
 inline
-arma_hot
 bool
 SpMat<eT>::const_row_iterator::operator==(const typename SpSubview<eT>::const_row_iterator& rhs) const
   {
@@ -912,7 +884,6 @@ SpMat<eT>::const_row_iterator::operator==(const typename SpSubview<eT>::const_ro
 
 template<typename eT>
 inline
-arma_hot
 bool
 SpMat<eT>::const_row_iterator::operator!=(const typename SpSubview<eT>::const_row_iterator& rhs) const
   {
@@ -927,7 +898,6 @@ SpMat<eT>::const_row_iterator::operator!=(const typename SpSubview<eT>::const_ro
 
 template<typename eT>
 inline
-arma_hot
 SpValProxy< SpMat<eT> >
 SpMat<eT>::row_iterator::operator*()
   {
@@ -942,7 +912,6 @@ SpMat<eT>::row_iterator::operator*()
 
 template<typename eT>
 inline
-arma_hot
 typename SpMat<eT>::row_iterator&
 SpMat<eT>::row_iterator::operator++()
   {
@@ -955,7 +924,6 @@ SpMat<eT>::row_iterator::operator++()
 
 template<typename eT>
 inline
-arma_warn_unused
 typename SpMat<eT>::row_iterator
 SpMat<eT>::row_iterator::operator++(int)
   {
@@ -970,7 +938,6 @@ SpMat<eT>::row_iterator::operator++(int)
 
 template<typename eT>
 inline
-arma_hot
 typename SpMat<eT>::row_iterator&
 SpMat<eT>::row_iterator::operator--()
   {
@@ -983,7 +950,6 @@ SpMat<eT>::row_iterator::operator--()
 
 template<typename eT>
 inline
-arma_warn_unused
 typename SpMat<eT>::row_iterator
 SpMat<eT>::row_iterator::operator--(int)
   {
