@@ -168,6 +168,14 @@
   // gcc 6.1 has proper C++14 support and fixes an OpenMP related bug:
   // https://gcc.gnu.org/bugzilla/show_bug.cgi?id=57580
   
+  #if (ARMA_GCC_VERSION < 80100)
+    #pragma message("INFO: support for GCC versions older than 8.1 is deprecated")
+  #endif
+  
+  #if (ARMA_GCC_VERSION >= 170000)
+    #undef ARMA_IGNORE_DEPRECATED_MARKER
+  #endif
+  
   #define ARMA_GOOD_COMPILER
   
   #undef  arma_hot
@@ -225,6 +233,12 @@
   
   // #pragma message ("using Clang extensions")
   
+  #if defined(__clang_major__) && !defined(__apple_build_version__)
+    #if (__clang_major__ >= 24)
+      #undef ARMA_IGNORE_DEPRECATED_MARKER
+    #endif
+  #endif
+  
   #define ARMA_GOOD_COMPILER
   
   #if !defined(__has_attribute)
@@ -304,15 +318,13 @@
   #endif
   
   #undef  ARMA_HAVE_GCC_ASSUME_ALIGNED
-  #undef  ARMA_HAVE_ICC_ASSUME_ALIGNED
-  #define ARMA_HAVE_ICC_ASSUME_ALIGNED
   
 #endif
 
 
 #if defined(_MSC_VER)
   
-  #if (_MSC_VER < 1900)
+  #if (_MSC_VER < 1910)
     #error "*** newer compiler required ***"
   #endif
   
@@ -475,11 +487,10 @@
 #undef major
 
 
-// optionally allow disabling of compile-time deprecation messages (not recommended)
-// NOTE: option 'ARMA_IGNORE_DEPRECATED_MARKER' will be removed
-// NOTE: disabling deprecation messages is counter-productive
+// WARNING: option 'ARMA_IGNORE_DEPRECATED_MARKER' is not supported when compiling with gcc 17+ or clang 24+
+// WARNING: disabling deprecation messages is counter-productive
 
-#if defined(ARMA_IGNORE_DEPRECATED_MARKER) && (!defined(ARMA_DONT_IGNORE_DEPRECATED_MARKER)) && (!defined(ARMA_DEBUG))
+#if defined(ARMA_IGNORE_DEPRECATED_MARKER)
   #undef  arma_deprecated
   #define arma_deprecated
 
