@@ -1,3 +1,5 @@
+// SPDX-License-Identifier: Apache-2.0
+// 
 // Copyright 2008-2016 Conrad Sanderson (http://conradsanderson.id.au)
 // Copyright 2008-2016 National ICT Australia (NICTA)
 // 
@@ -46,8 +48,8 @@ class op_any
   any_vec_helper
     (
     const mtOp<uword, T1, op_type>& X,
-    const typename arma_op_rel_only<op_type>::result*           junk1 = 0,
-    const typename arma_not_cx<typename T1::elem_type>::result* junk2 = 0
+    const typename arma_op_rel_only<op_type>::result*           junk1 = nullptr,
+    const typename arma_not_cx<typename T1::elem_type>::result* junk2 = nullptr
     );
   
   
@@ -56,9 +58,9 @@ class op_any
   any_vec_helper
     (
     const mtGlue<uword, T1, T2, glue_type>& X,
-    const typename arma_glue_rel_only<glue_type>::result*       junk1 = 0,
-    const typename arma_not_cx<typename T1::elem_type>::result* junk2 = 0,
-    const typename arma_not_cx<typename T2::elem_type>::result* junk3 = 0
+    const typename arma_glue_rel_only<glue_type>::result*       junk1 = nullptr,
+    const typename arma_not_cx<typename T1::elem_type>::result* junk2 = nullptr,
+    const typename arma_not_cx<typename T2::elem_type>::result* junk3 = nullptr
     );
   
   
@@ -66,9 +68,11 @@ class op_any
   static inline bool any_vec(T1& X);
   
   
-  template<typename T1>
-  static inline void apply_helper(Mat<uword>& out, const Proxy<T1>& P, const uword dim);
+  template<typename eT>
+  static inline void apply_mat_noalias(Mat<uword>& out, const Mat<eT>& X, const uword dim);
   
+  template<typename T1>
+  static inline void apply_proxy_noalias(Mat<uword>& out, const Proxy<T1>& P, const uword dim);
   
   template<typename T1>
   static inline void apply(Mat<uword>& out, const mtOp<uword, T1, op_any>& X);
